@@ -1,7 +1,9 @@
 use xmu_health_report_rust_sdk::{
-  create_client, get_system_date, is_today_reported, login, pipeline, report, PipelineStage,
-  ReportStage,
+  create_client, get_system_date, is_today_reported, login, pipeline, report,
 };
+use xmu_health_report_rust_sdk::{PipelineStage, ReportStage};
+
+use std::collections::HashMap;
 
 use clap::{App, AppSettings, Arg};
 
@@ -68,7 +70,7 @@ async fn main() -> Result<(), anyhow::Error> {
 
     let client = create_client().await?;
     login(&client, username, password).await?;
-    let report_result = report(&client).await?;
+    let report_result = report(&client, &HashMap::new()).await?;
 
     println!(
       "打卡状态: {}",
