@@ -2,8 +2,6 @@ use reqwest::Client;
 
 use serde_json::{from_str, Value};
 
-use std::error::Error;
-
 use crate::print_on_debug_env;
 use super::client::get;
 use super::constant::{
@@ -73,7 +71,7 @@ pub async fn modify_log(client: &Client) -> Result<ModifyLogResult, anyhow::Erro
 ///
 /// @param `client: &Client`
 ///
-/// @return `Result<bool, Box<dyn Error>>`
+/// @return `Result<bool, anyhow::Error>`
 pub async fn is_today_reported(client: &Client) -> Result<(bool, String), anyhow::Error> {
   let modify_log_result = modify_log(&client).await?;
   let today_date = get_system_date();
@@ -88,13 +86,13 @@ pub async fn is_today_reported(client: &Client) -> Result<(bool, String), anyhow
 ///
 /// @param `client: &Client`
 ///
-/// @return `Result<bool, Box<dyn Error>>
-pub async fn get_continuous_report_day_count(client: &Client) -> Result<i64, Box<dyn Error>> {
+/// @return `Result<i64, anyhow::Error>
+pub async fn get_continuous_report_day_count(client: &Client) -> Result<i64, anyhow::Error> {
   let resp = get(&client, QRCODE_URL).await?;
   let resp_json: Value = from_str(&resp)?;
   let days_count_str = resp_json["data"]["clockDay"]
     .as_str()
-    .ok_or("Cannot destruct clockDay.")?;
+    .ok_or(anyhow!("Cannot destruct clockDay."))?;
 
   let days_count = days_count_str.parse::<i64>()?;
 
@@ -105,13 +103,13 @@ pub async fn get_continuous_report_day_count(client: &Client) -> Result<i64, Box
 /// 
 /// @param `client: &Client`
 /// 
-/// @return `Result<ProfileResult, Box<dyn Error>>`
-pub async fn get_profile(client: &Client) -> Result<ProfileResult, Box<dyn Error>> {
+/// @return `Result<ProfileResult, anyhow::Error>`
+pub async fn get_profile(client: &Client) -> Result<ProfileResult, anyhow::Error> {
   let resp = get(&client, PROFILE_URL).await?;
   let resp_json: Value = from_str(&resp)?;
 
-  let name = resp_json["data"]["name"].as_str().ok_or("parse name failed")?;
-  let id = resp_json["data"]["userNo"].as_str().ok_or("parse id failed")?;
+  let name = resp_json["data"]["name"].as_str().ok_or(anyhow!("parse name failed"))?;
+  let id = resp_json["data"]["userNo"].as_str().ok_or(anyhow!("parse id failed"))?;
 
   Ok(ProfileResult {
     name: name.to_string(),
