@@ -1,4 +1,5 @@
-use chrono::{DateTime, Utc};
+use chrono::{DateTime, Local};
+use std::time::{SystemTime, UNIX_EPOCH};
 
 #[macro_export]
 macro_rules! print_on_debug_env {
@@ -18,8 +19,16 @@ macro_rules! print_on_debug_env {
 
 /// 获取当前系统日期，格式为 YYYY-MM-DD
 pub fn get_system_date() -> String {
-  let now: DateTime<Utc> = Utc::now();
+  let now: DateTime<Local> = Local::now();
   let result = format!("{}", now.format("%Y-%m-%d"));
 
   result
 }
+
+/// 获取时间戳
+pub fn get_timestamp() -> u128 {
+    SystemTime::now()
+        .duration_since(UNIX_EPOCH)
+        .unwrap()
+        .as_millis()
+}
\ No newline at end of file
